TempoEthExtApiServer

Trait TempoEthExtApiServer 

pub trait TempoEthExtApiServer:
    Sized
    + Send
    + Sync
    + 'static {
    // Required method
    fn transactions<'life0, 'async_trait>(
        &'life0 self,
        params: PaginationParams<TransactionsFilter>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<TransactionsResponse>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided method
    fn into_rpc(self) -> RpcModule<Self> { ... }
}
Server trait implementation for the TempoEthExtApi RPC API.

Required Methods

fn transactions<'life0, 'async_trait>( &'life0 self, params: PaginationParams<TransactionsFilter>, ) -> Pin<Box<dyn Future<Output = RpcResult<TransactionsResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Gets paginated transactions on Tempo with flexible filtering and sorting.

Uses cursor-based pagination for stable iteration through transactions.

Provided Methods

fn into_rpc(self) -> RpcModule<Self>

Collects all the methods and subscriptions defined in the trait and adds them into a single RpcModule.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<EthApi: RpcNodeCore> TempoEthExtApiServer for TempoEthExt<EthApi>